# py-pylpsd

 Python implementation of the pylpsd algorithm for computing power spectral density with logarithmically spaced points. 

## Installation

This package can be installed via pip:

```
pip install pylpsd
```

In case you want to edit this, clone this repository and install it in editable mode:

```
git clone https://github.com/bleykauf/py-lpsd
cd py-lpsd
pip install -e .
```

## Usage
See the Jupyter notebook in the examples folder and the docstring.

 ## Implementation in other languages

 [Matlab](https://github.com/tobin/lpsd): py-lpsd is based on this implementation.
